==> download.php?d=bsmyjspace_pack_2.6.0_PACK.zip: uninstall.myjspace.php <==
<?php
/**
* @version $Id: uninstall.myjspace.php $
* @version		2.6.0 28/04/2016
* @package		com_myjspace
* @author       Bernard Saulmé
* @copyright	Copyright (C) 2010-2011-2012-2013-2014-2015-2016 Bernard Saulmé
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die;

?>
<h1>MyJspace Uninstall</h1>
<?php
	// Config
	$pparams = JComponentHelper::getParams('com_myjspace');
	$foldername = $pparams->get('foldername', 'myjsp');
	$db	= JFactory::getDBO();		

	if ($pparams->get('uninstall_tables', 0) == 0) { // Drop tables & content
		// Get old content, save the content into param and drop old table #__myjspace_cfg
		echo "<p>Recreating a #__myjspace_cfg table and it's content to keep in 'mind' the root folder name ...<br /></p>";

		$query = "CREATE TABLE IF NOT EXISTS `#__myjspace_cfg` ( `foldername` varchar(100) NOT NULL, PRIMARY KEY (`foldername`) ) ENGINE=MyISAM DEFAULT CHARSET=utf8";
		$db->setQuery($query);
		$db->query();

		$query = "DELETE FROM `#__myjspace_cfg`";
		$db->setQuery($query);
		$db->query();

		$query = "INSERT INTO `#__myjspace_cfg` (`foldername`) VALUES (".$db->Quote($foldername).");";
		$db->setQuery($query);
		$db->query();
?>
	<p>
	<b><u>bye bye :-(</u></b><br /><br />
	BS MyJspace tables (with user's data) and folder were not deleted during this uninstall process<br />
	If you don't want theses: delete manually folder '<?php echo $foldername; ?>' and tables #__myjspace and #__myjspace_cfg<br />
	</p>
<?php 
	}
?>

==> download.php?d=bsmyjspace_pack_2.6.10_PACK.zip: uninstall.myjspace.php <==
<?php
/**
* @version $Id: uninstall.myjspace.php $
* @version		2.6.6 08/05/2019
* @package		com_myjspace
* @author       Bernard Saulmé
* @copyright	Copyright (C) 2010 - 2019 Bernard Saulmé
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

defined('_JEXEC') or die;
?>
<h1>MyJspace Uninstall</h1>
<?php
	// Config
	$pparams = JComponentHelper::getParams('com_myjspace');
	$foldername = $pparams->get('foldername', 'myjsp');
	$db	= JFactory::getDBO();		

	if ($pparams->get('uninstall_tables', 0) == 0) { // Drop tables & content
		// Get old content, save the content into param and drop old table #__myjspace_cfg
		echo "<p>Recreating a #__myjspace_cfg table and it's content to keep in 'mind' the root folder name ...<br /></p>";

		$query = "CREATE TABLE IF NOT EXISTS `#__myjspace_cfg` ( `foldername` varchar(100) NOT NULL, PRIMARY KEY (`foldername`) ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 DEFAULT COLLATE=utf8mb4_unicode_ci;";
		$db->setQuery($query);
		$db->query();

		$query = "DELETE FROM `#__myjspace_cfg`";
		$db->setQuery($query);
		$db->query();

		$query = "INSERT INTO `#__myjspace_cfg` (`foldername`) VALUES (".$db->Quote($foldername).");";
		$db->setQuery($query);
		$db->query();
?>
	<p>
	<b><u>bye bye :-(</u></b><br /><br />
	BS MyJspace tables (with user's data) and folder were not deleted during this uninstall process<br />
	If you don't want theses: delete manually folder '<?php echo $foldername; ?>' and tables #__myjspace and #__myjspace_cfg<br />
	</p>
<?php 
	}
?>
